[−][src]Crate vtkio
Modules
| basic | |
| model | |
| parser | |
| writer |
Macros
| call_numeric_buffer_fn | Applies |
Enums
| Error | Error type for Import/Export operations. |
Functions
| export | Export given vtk data to the specified file in BINARY format. |
| export_ascii | Export given vtk data to the specified file in ASCII format. |
| export_be | Same as |
| export_le | Same as |
| import | Import a vtk file at the specified path. |
| import_be | Import a vtk file at the specified path. If the file is in binary, numeric types will be interpreted in big-endian format. |
| import_le | Import a vtk file at the specified path. If the file is in binary, numeric types will be interpreted in little-endian format. |
Type Definitions
| IOBuffer | Primary buffer type used to store data read from binary or ASCII files. |