[−][src]Module vtkio::model
Structs
| Attributes | Point and cell attributes. |
| Cells | Cell data. Used in |
| FieldArray | Special struct to store Field attribute data. |
| Version | Version number (e.g. |
| Vtk | Vtk Data Model Model of the Vtk data structure. |
Enums
| Attribute | Data structure that stores a Vtk attribute. |
| CellType | This enum describes the types of Cells representable by vtk files. These are explicitly written
in |
| DataSet | Dataset described in the file.
For 2D objects, |
| DataType | Types of data that can be recognized by the parser. Not all data types are supported for all classes. |
| PolyDataTopology |